==> haskell-pandoc-types-1.17.0.4-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.0.4
id: pandoc-types-1.17.0.4-38O9nObzU9BCB3ScP1sssz
key: pandoc-types-1.17.0.4-38O9nObzU9BCB3ScP1sssz
license: BSD3
copyright: (c) 2006-2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.Pandoc.Definition Text.Pandoc.Generic Text.Pandoc.Walk
    Text.Pandoc.Builder Text.Pandoc.JSON Text.Pandoc.Arbitrary
hidden-modules: Paths_pandoc_types
abi: ee7a4dcb85611ce9010eb8ce488651fa
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.17.0.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.17.0.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/pandoc-types-1.17.0.4
hs-libraries: HSpandoc-types-1.17.0.4-38O9nObzU9BCB3ScP1sssz
depends:
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s
    aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    ghc-prim-0.5.0.0 syb-0.6-C65vWCsht6A8uLstpQIXyj
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.17.0.4-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.0.4
id: pandoc-types-1.17.0.4-GnvbURmMLwWDWlWEAC77Jv
key: pandoc-types-1.17.0.4-GnvbURmMLwWDWlWEAC77Jv
license: BSD3
copyright: (c) 2006-2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.Pandoc.Definition Text.Pandoc.Generic Text.Pandoc.Walk
    Text.Pandoc.Builder Text.Pandoc.JSON Text.Pandoc.Arbitrary
hidden-modules: Paths_pandoc_types
abi: eb1895cb4b9d6833d4b6cfe1fd80f691
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.17.0.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.17.0.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/pandoc-types-1.17.0.4
hs-libraries: HSpandoc-types-1.17.0.4-GnvbURmMLwWDWlWEAC77Jv
depends:
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    ghc-prim-0.5.0.0 syb-0.6-C65vWCsht6A8uLstpQIXyj
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
